@@ -104,7 +104,7 @@ def find_root_redshift(func):
     zmin = 1e-8
     log_opt(zmin)
     # steadily shift the z range if we don't find a root
-    for zmax in [1, 10, 100]:
+    for zmax in [0.1, 1, 10, 100]:
         log_opt(zmax)
         try:
             return scipy.optimize.brentq(func, zmin, zmax)
